==> libapache-poi-java_3.10.1.orig.tar.xz: apache-poi-3.10.1/src/ooxml/java/org/apache/poi/xssf/usermodel/charts/XSSFChartDataFactory.java <==
/* ====================================================================
   Licensed to the Apache Software Foundation (ASF) under one or more
   contributor license agreements.  See the NOTICE file distributed with
   this work for additional information regarding copyright ownership.
   The ASF licenses this file to You under the Apache License, Version 2.0
   (the "License"); you may not use this file except in compliance with
   the License.  You may obtain a copy of the License at

       http://www.apache.org/licenses/LICENSE-2.0

   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.
==================================================================== */

package org.apache.poi.xssf.usermodel.charts;

import org.apache.poi.ss.usermodel.charts.*;
import org.apache.poi.util.Beta;

/**
 * @author Roman Kashitsyn
 */
@Beta
public class XSSFChartDataFactory implements ChartDataFactory {

	private static XSSFChartDataFactory instance;

	private XSSFChartDataFactory() {
		super();
	}

	/**
	 * @return new scatter charts data instance
	 */
	public XSSFScatterChartData createScatterChartData() {
		return new XSSFScatterChartData();
	}

	/**
	 * @return new line charts data instance
	 */
	public XSSFLineChartData createLineChartData() {
		return new XSSFLineChartData();
	}

	/**
	 * @return factory instance
	 */
	public static XSSFChartDataFactory getInstance() {
		if (instance == null) {
			instance = new XSSFChartDataFactory();
		}
		return instance;
	}

}

==> libapache-poi-java_4.0.1.orig.tar.xz: apache-poi-4.0.1/src/ooxml/java/org/apache/poi/xssf/usermodel/charts/XSSFChartDataFactory.java <==
/* ====================================================================
   Licensed to the Apache Software Foundation (ASF) under one or more
   contributor license agreements.  See the NOTICE file distributed with
   this work for additional information regarding copyright ownership.
   The ASF licenses this file to You under the Apache License, Version 2.0
   (the "License"); you may not use this file except in compliance with
   the License.  You may obtain a copy of the License at

       http://www.apache.org/licenses/LICENSE-2.0

   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.
==================================================================== */

package org.apache.poi.xssf.usermodel.charts;

import org.apache.poi.ss.usermodel.charts.ChartDataFactory;
import org.apache.poi.util.Removal;

/**
 * @deprecated
 */
@Deprecated
@Removal(version="4.2")
public class XSSFChartDataFactory implements ChartDataFactory {

	private static XSSFChartDataFactory instance;

	private XSSFChartDataFactory() {
		super();
	}

	/**
	 * @return new scatter charts data instance
	 */
	@Override
    public XSSFScatterChartData createScatterChartData() {
		return new XSSFScatterChartData();
	}

	/**
	 * @return new line charts data instance
	 */
	@Override
    public XSSFLineChartData createLineChartData() {
		return new XSSFLineChartData();
	}

	/**
	 * @return factory instance
	 */
	public static XSSFChartDataFactory getInstance() {
		if (instance == null) {
			instance = new XSSFChartDataFactory();
		}
		return instance;
	}

}
